@@ -140,6 +140,7 @@ class FrameProcessor(object):
         return string[:self.max_str_length], len(string) > self.max_str_length
 
     def clone(self, tracepoint):
+        # type: (Breakpoint) -> FrameProcessor
         processor = FrameProcessor(self.config, self.client_config)
         processor.var_cache = dict(self.var_cache)
         processor.var_lookup = dict(self.var_lookup)
@@ -155,6 +156,13 @@ class FrameProcessor(object):
             processor.trim_frames()
             processor.var_lookup = {}
 
+        # add the basic tags for the snapshot
+        processor.tags['line'] = tracepoint.line_no
+        processor.tags['file'] = tracepoint.rel_path
+        processor.tags['type'] = tracepoint.type
+        if 'workspace' in tracepoint.args:
+            processor.tags['workspace'] = tracepoint.args['workspace']
+
         if 'tag_keys' in tracepoint.args:
             tag_keys = tracepoint.args['tag_keys'].split(',')
             for tag_key_raw in tag_keys:
