@@ -17,14 +17,14 @@ nv_settings = {
 
     # ----------------------------------------------------------------------------
     # Defines the license key to use and api locations
-    'api_url': os.environ.get("NV_API_URL") or "https://api.nerd.vision",
+    'api_url': os.environ.get("NV_API_URL") or "https://api.sls.nerd.vision",
     'api_key': os.environ.get("NV_API_KEY") or None,
 
-    'license_url': os.environ.get("NV_LICENSE_URL") or 'https://api.sls.nerd.vision',
+    'license_url': os.environ.get("NV_LICENSE_URL") or None,
     'license_api': os.environ.get("NV_LICENSE_API") or "/nvcr/v1/registration",
 
-    # Defines the grpc url. defaults to api.url
-    'grpc_url': os.environ.get("NV_GRPC_URL") or None,
+    # Defines the grpc url
+    'grpc_url': os.environ.get("NV_GRPC_URL") or "https://grpc.nerd.vision",
     # Define the grpc port number
     'grpc_port': os.environ.get("NV_GRPC_PORT") or 443,
     # Define the grpc reconnect attempt intervals
@@ -34,9 +34,10 @@ nv_settings = {
     'client_registration_backoff_max': os.environ.get("NV_CLIENT_REGISTRATION_BACKOFF_MAX") or 120,
     'client_registration_backoff_multiplier': os.environ.get("NV_CLIENT_REGISTRATION_BACKOFF_MULTIPLIER") or 1.2,
 
+    # Defines the snapshot api url. defaults to api.url
+    'event_snapshot_url': os.environ.get("NV_EVENT_SNAPSHOT_URL") or None,
     # The end point for the event snapshot
     'event_snapshot_api': os.environ.get("NV_EVENT_SNAPSHOT_API") or "/v1/context/",
-    'event_snapshot_url': os.environ.get("NV_EVENT_SNAPSHOT_URL") or "https://api.sls.nerd.vision",
 
     # ----------------------------------------------------------------------------
     # Defines the regex for the ENV section of the client registration step.
@@ -55,8 +56,8 @@ nv_settings = {
     # Defines the rate limit for breakpoints to fire in ms
     'bp_rate_limit': os.environ.get("NV_BP_RATE_LIMIT") or 100,
 
-    # Defines the error api url
-    'error_ingest_url': os.environ.get("NV_ERROR_INGEST_URL") or "https://api.sls.nerd.vision",
+    # Defines the error api url. defaults to api.url
+    'error_ingest_url': os.environ.get("NV_ERROR_INGEST_URL") or None,
     'error_ingest_api': os.environ.get("NV_ERROR_INGEST_API") or "/error",
 
     'source_capture': False,
